#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# If you use this code, cite as
# [1] Y.W. Park and D. Klabjan, Iteratively reweighted least squares algorithms for l1-norm principal component analysis, 2016 IEEE International Conference on Data Mining (ICDM), Barcelona, Spain, 2016, pp. 430-438.
# preprint available at http://arxiv.org/abs/1609.02997

# Functions included: wl1pca, awl1pca, SSVD, awl1pca.ssvd
# wl1pca and awl1pca correspond to Algorithms 1 and 2, respectively, in the reference paper [1], and wl1pca.ssvd is a new algorithm not presented in the reference paper [1]
# Date: Feb 13, 2017
# Version: 1.1
# Comments:
# Most of the arguments, return values, and their definitions follow the package "pcaL1" by Jot and Brooks (2015)
#
# Version information
# Version 1.01 (Sep 17, 2016): the first version 
# Version 1.1 (Feb 13, 2017): (a) awl1pca.ssvd is added
#                             (b) weighted matrix generation code is changed due to memory inefficiencies with large size data
#                             (c) prcomp function is replaced by svd



source("wl1pca.r")

p <- 2 # number of PC

# Usage with iris data
wl1pca.result <- wl1pca(as.matrix(iris[,1:4]), projDim=p)
wl1pca.result2 <- wl1pca(as.matrix(iris[,1:4]), projDim=p, center=TRUE, tolerance=0.001, iterations=200, beta = 0.99)
awl1pca.result <- awl1pca(as.matrix(iris[,1:4]), projDim=p)
awl1pca.result2 <- awl1pca(as.matrix(iris[,1:4]), projDim=p, center=TRUE, tolerance=0.001, iterations=200, beta = 0.99, gamma = 0.1)


